##  Simple Relation Strategy
To choose the simple relation strategy, do the following:
  1. In the Collibra Integration Configuration area, go to the Relation Mapping tab.
  2. From the Relation Mapping Strategy drop-down list, choose Simple Relation.
  3. Once the simple relation is selected, the Relation Type field appears. Choose the required type from the drop-down list.
![Configuring Relations Using the Simple Relation Strategy](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749f5e67a441014a1eed0eaecb60415_LowRes.png)
Configuring Relations Using the Simple Relation Strategy


![Relation Between Application and Data Object Mapped to Asset in Collibra Choosing Simple Relation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757cb767a441014804dbb62c0f896c8_LowRes.png)
Relation Between Application and Data Object Mapped to Relation Between Assets in Collibra Choosing Simple Relation
